@@ -11,7 +11,12 @@ import publication
 import aws_cdk.core._jsii
 import constructs._jsii
 
-__jsii_assembly__ = jsii.JSIIAssembly.load("@aws-cdk/aws-mediastore", "1.44.0", __name__[0:-6], "aws-mediastore@1.44.0.jsii.tgz")
+__jsii_assembly__ = jsii.JSIIAssembly.load(
+    "@aws-cdk/aws-mediastore",
+    "1.58.0",
+    __name__[0:-6],
+    "aws-mediastore@1.58.0.jsii.tgz",
+)
 
 __all__ = [
     "__jsii_assembly__",
